(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     49028,        970]
NotebookOptionsPosition[     49419,        960]
NotebookOutlinePosition[     49884,        980]
CellTagsIndexPosition[     49841,        977]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Principle of Stress Superposition\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2018-02-03",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell["\<\
This module is designed to demonstrate the superposition of deformation or \
strain of a cube in 3D. 
The principle of superposition is often used to determine the stress, strain \
or displacement of a point in a cube when the cube is subjected to a \
complicated loading. By subdividing the loading into components, the \
principle of superposition states that the resultant stress, strain or \
displacement at a point can be determined by algebraically summing the \
stress, strain or displacement caused by each component applied separately to \
the cube. 
In the present module, complex stress loading can be applied on the cube. \
However, the stress can be divided into six components, and we can calculate \
the strain of cube under each stress component. Then the total strain will be \
the sum of these six strain. 
This principle will be used whenever the Hooke\[CloseCurlyQuote]s law \
applies, which means there is a linear relation between stress and strain. \
Also, the small deformation assumption needs to be hold as a prerequisite, \
which means the loading must not significantly change the original geometry \
or configuration of the member. In order to see the deformation clearly, we \
set a variable \[OpenCurlyDoubleQuote]deformation scaling\
\[CloseCurlyDoubleQuote] to enlarge the deformation shown on the figure while \
do not change the actual strain value. \
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`exa$$ = 50, $CellContext`ey$$ = 
    210, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = GrayLevel[
    1], $CellContext`opa3$$ = False, $CellContext`reset$$ = 
    False, $CellContext`\[Nu]$$ = 0.3, $CellContext`\[Sigma]x$$ = 
    0, $CellContext`\[Sigma]y$$ = 0, $CellContext`\[Sigma]z$$ = 
    0, $CellContext`\[Tau]xy$$ = 0, $CellContext`\[Tau]yz$$ = 
    0, $CellContext`\[Tau]zx$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`\[Sigma]x$$], 0, ""}, -500, 500, 5.}, {{
       Hold[$CellContext`\[Sigma]y$$], 0, ""}, -500, 500, 5.}, {{
       Hold[$CellContext`\[Sigma]z$$], 0, ""}, -500, 500, 5.}, {{
       Hold[$CellContext`\[Tau]xy$$], 0, ""}, -500, 500, 5.}, {{
       Hold[$CellContext`\[Tau]yz$$], 0, ""}, -500, 500, 5.}, {{
       Hold[$CellContext`\[Tau]zx$$], 0, ""}, -500, 500, 5.}, {{
       Hold[$CellContext`ey$$], 210, ""}, 50, 250, 10}, {{
       Hold[$CellContext`\[Nu]$$], 0.3, ""}, -1, 0.5, 0.1}, {{
       Hold[$CellContext`exa$$], 50, ""}, 1, 100, 1}, {{
       Hold[$CellContext`opa3$$], False, Null}, {
      True -> "On", False -> "Off"}}, {{
       Hold[$CellContext`opa2$$], 
       GrayLevel[1], Null}, {GrayLevel[0] -> "On", GrayLevel[1] -> "Off"}}, {{
       Hold[$CellContext`opa1$$], 0, Null}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Grid[{{
             Row[{
               Text[
                Style["Stress"]], 
               Text[" (MPa)"]}], SpanFromLeft}, {
             Row[{
               Text[
                Subscript["\[Sigma]", "xx"]]}], 
             Manipulate`Place[1]}, {
             Row[{
               Text[
                Subscript["\[Sigma]", "yy"]]}], 
             Manipulate`Place[2]}, {
             Row[{
               Text[
                Subscript["\[Sigma]", "zz"]]}], 
             Manipulate`Place[3]}, {
             Row[{
               Text[
                Subscript["\[Tau]", "xy"]]}], 
             Manipulate`Place[4]}, {
             Row[{
               Text[
                Subscript["\[Tau]", "yz"]]}], 
             Manipulate`Place[5]}, {
             Row[{
               Text[
                Subscript["\[Tau]", "zx"]]}], 
             Manipulate`Place[6]}}, Alignment -> Left]}, {}, {
          Grid[{{
             Grid[{{
                Text["Young's Modulus (GPa)"]}, {
                Manipulate`Place[7]}}, Alignment -> Left]}, {
             Grid[{{
                Text["Poisson's Ratio"]}, {
                Manipulate`Place[8]}}, Alignment -> Left]}, {
             Grid[{{
                Row[{
                  Text[
                   Style["Deformation scaling"]]}]}, {
                Manipulate`Place[9]}}, Alignment -> Left]}}, Alignment -> 
           Left]}, {
          Grid[{{
             Row[{
               Text["Show original"]}]}, {
             Manipulate`Place[10]}, {
             Row[{
               Text["Strain tensor"], 
               Text[" (\[Times]"], 
               Text[
                Superscript["10", "-3"]], 
               Text[")"]}]}, {
             Manipulate`Place[11]}, {
             Text["Superposition"]}, {
             Manipulate`Place[12]}, {}, {
             Button[
              Text["reset view"], $CellContext`reset$$ = True, 
              ImageSize -> {95, 25}]}, {
             Button[
              Text[
              "reset stress"], $CellContext`\[Sigma]x$$ = 
               0; $CellContext`\[Sigma]y$$ = 0; $CellContext`\[Sigma]z$$ = 
               0; $CellContext`\[Tau]xy$$ = 0; $CellContext`\[Tau]yz$$ = 
               0; $CellContext`\[Tau]zx$$ = 0, ImageSize -> {95, 25}]}}, 
           Alignment -> Left]}}, Alignment -> Left]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`reset$$], False}, 0}}, Typeset`size$$ = {
    1281., {354., 363.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`\[Sigma]x$19421$$ = 
    0, $CellContext`\[Sigma]y$19422$$ = 0, $CellContext`\[Sigma]z$19423$$ = 
    0, $CellContext`\[Tau]xy$19424$$ = 0, $CellContext`\[Tau]yz$19425$$ = 
    0, $CellContext`\[Tau]zx$19426$$ = 0, $CellContext`ey$19427$$ = 
    0, $CellContext`\[Nu]$19428$$ = 0, $CellContext`exa$19429$$ = 
    0, $CellContext`opa3$19430$$ = False, $CellContext`opa2$19431$$ = 
    False, $CellContext`opa1$19432$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`exa$$ = 50, $CellContext`ey$$ = 
        210, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 
        GrayLevel[1], $CellContext`opa3$$ = False, $CellContext`reset$$ = 
        False, $CellContext`\[Nu]$$ = 0.3, $CellContext`\[Sigma]x$$ = 
        0, $CellContext`\[Sigma]y$$ = 0, $CellContext`\[Sigma]z$$ = 
        0, $CellContext`\[Tau]xy$$ = 0, $CellContext`\[Tau]yz$$ = 
        0, $CellContext`\[Tau]zx$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`\[Sigma]x$$, $CellContext`\[Sigma]x$19421$$, 0], 
        Hold[$CellContext`\[Sigma]y$$, $CellContext`\[Sigma]y$19422$$, 0], 
        Hold[$CellContext`\[Sigma]z$$, $CellContext`\[Sigma]z$19423$$, 0], 
        Hold[$CellContext`\[Tau]xy$$, $CellContext`\[Tau]xy$19424$$, 0], 
        Hold[$CellContext`\[Tau]yz$$, $CellContext`\[Tau]yz$19425$$, 0], 
        Hold[$CellContext`\[Tau]zx$$, $CellContext`\[Tau]zx$19426$$, 0], 
        Hold[$CellContext`ey$$, $CellContext`ey$19427$$, 0], 
        Hold[$CellContext`\[Nu]$$, $CellContext`\[Nu]$19428$$, 0], 
        Hold[$CellContext`exa$$, $CellContext`exa$19429$$, 0], 
        Hold[$CellContext`opa3$$, $CellContext`opa3$19430$$, False], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$19431$$, False], 
        Hold[$CellContext`opa1$$, $CellContext`opa1$19432$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$, $CellContext`k$}, $CellContext`s = 
         500; $CellContext`\[Tau] = 
         500; $CellContext`e = $CellContext`ey$$ 10^9; $CellContext`k$ = 
         1; $CellContext`stunit = 
         10^6; $CellContext`g$ = $CellContext`e/(
          2 (1 + $CellContext`\[Nu]$$)); $CellContext`imz0 = 
         349; $CellContext`imz1 = 150; $CellContext`lps = 
         0.3; $CellContext`fsz1 = 0.06; $CellContext`fsz2 = 
         0.04; $CellContext`arn = 0.2; $CellContext`art = 
         0.45; $CellContext`exa2 = 10^3; $CellContext`ft = 
         12; $CellContext`ahd = 0.04; $CellContext`ahs = 
         0.02; $CellContext`td = 0.005; $CellContext`ts = 
         0.005; $CellContext`sclsup = 
         0.8; $CellContext`reset1 = $CellContext`reset$$; $CellContext`reset2 = \
$CellContext`reset$$; $CellContext`reset3 = $CellContext`reset$$; \
$CellContext`reset4 = $CellContext`reset$$; $CellContext`reset5 = \
$CellContext`reset$$; $CellContext`reset6 = $CellContext`reset$$; \
$CellContext`\[Epsilon]x0 = ($CellContext`exa$$ $CellContext`stunit) \
($CellContext`\[Sigma]x$$/$CellContext`e - \
($CellContext`\[Nu]$$/$CellContext`e) ($CellContext`\[Sigma]y$$ + \
$CellContext`\[Sigma]z$$)); $CellContext`\[Epsilon]y0 = ($CellContext`exa$$ \
$CellContext`stunit) ($CellContext`\[Sigma]y$$/$CellContext`e - \
($CellContext`\[Nu]$$/$CellContext`e) ($CellContext`\[Sigma]x$$ + \
$CellContext`\[Sigma]z$$)); $CellContext`\[Epsilon]z0 = ($CellContext`exa$$ \
$CellContext`stunit) ($CellContext`\[Sigma]z$$/$CellContext`e - \
($CellContext`\[Nu]$$/$CellContext`e) ($CellContext`\[Sigma]x$$ + \
$CellContext`\[Sigma]y$$)); $CellContext`\[Gamma]xy0 = ($CellContext`exa$$ \
$CellContext`stunit) ($CellContext`\[Tau]xy$$/$CellContext`g$); $CellContext`\
\[Gamma]yz0 = ($CellContext`exa$$ $CellContext`stunit) \
($CellContext`\[Tau]yz$$/$CellContext`g$); $CellContext`\[Gamma]zx0 = \
($CellContext`exa$$ $CellContext`stunit) \
($CellContext`\[Tau]zx$$/$CellContext`g$); $CellContext`\[Epsilon]x1 = \
($CellContext`exa$$ $CellContext`stunit) ((
            1/$CellContext`e) $CellContext`\[Sigma]x$$); $CellContext`\
\[Epsilon]y1 = ($CellContext`exa$$ $CellContext`stunit) \
(((-$CellContext`\[Nu]$$)/$CellContext`e) $CellContext`\[Sigma]x$$); \
$CellContext`\[Epsilon]z1 = ($CellContext`exa$$ $CellContext`stunit) \
(((-$CellContext`\[Nu]$$)/$CellContext`e) $CellContext`\[Sigma]x$$); \
$CellContext`\[Gamma]xy1 = 0; $CellContext`\[Gamma]yz1 = 
         0; $CellContext`\[Gamma]zx1 = 
         0; $CellContext`\[Epsilon]x2 = ($CellContext`exa$$ \
$CellContext`stunit) (((-$CellContext`\[Nu]$$)/$CellContext`e) $CellContext`\
\[Sigma]y$$); $CellContext`\[Epsilon]y2 = ($CellContext`exa$$ \
$CellContext`stunit) ((
            1/$CellContext`e) $CellContext`\[Sigma]y$$); $CellContext`\
\[Epsilon]z2 = ($CellContext`exa$$ $CellContext`stunit) \
(((-$CellContext`\[Nu]$$)/$CellContext`e) $CellContext`\[Sigma]y$$); \
$CellContext`\[Gamma]xy2 = 0; $CellContext`\[Gamma]yz2 = 
         0; $CellContext`\[Gamma]zx2 = 
         0; $CellContext`\[Epsilon]x3 = ($CellContext`exa$$ \
$CellContext`stunit) (((-$CellContext`\[Nu]$$)/$CellContext`e) $CellContext`\
\[Sigma]z$$); $CellContext`\[Epsilon]y3 = ($CellContext`exa$$ \
$CellContext`stunit) (((-$CellContext`\[Nu]$$)/$CellContext`e) $CellContext`\
\[Sigma]z$$); $CellContext`\[Epsilon]z3 = ($CellContext`exa$$ \
$CellContext`stunit) ((
            1/$CellContext`e) $CellContext`\[Sigma]z$$); \
$CellContext`\[Gamma]xy3 = 0; $CellContext`\[Gamma]yz3 = 
         0; $CellContext`\[Gamma]zx3 = 0; $CellContext`\[Epsilon]x4 = 
         0; $CellContext`\[Epsilon]y4 = 0; $CellContext`\[Epsilon]z4 = 
         0; $CellContext`\[Gamma]xy4 = ($CellContext`exa$$ \
$CellContext`stunit) ($CellContext`\[Tau]xy$$/$CellContext`g$); $CellContext`\
\[Gamma]yz4 = 0; $CellContext`\[Gamma]zx4 = 0; $CellContext`\[Epsilon]x5 = 
         0; $CellContext`\[Epsilon]y5 = 0; $CellContext`\[Epsilon]z5 = 
         0; $CellContext`\[Gamma]xy5 = 
         0; $CellContext`\[Gamma]yz5 = ($CellContext`exa$$ \
$CellContext`stunit) ($CellContext`\[Tau]yz$$/$CellContext`g$); $CellContext`\
\[Gamma]zx5 = 0; $CellContext`\[Epsilon]x6 = 0; $CellContext`\[Epsilon]y6 = 
         0; $CellContext`\[Epsilon]z6 = 0; $CellContext`\[Gamma]xy6 = 
         0; $CellContext`\[Gamma]yz6 = 
         0; $CellContext`\[Gamma]zx6 = ($CellContext`exa$$ \
$CellContext`stunit) ($CellContext`\[Tau]zx$$/$CellContext`g$); \
{$CellContext`p10, $CellContext`p20, $CellContext`p30, $CellContext`p40, \
$CellContext`p50, $CellContext`p60, $CellContext`p70, $CellContext`p80} = \
$CellContext`getCoordinates[$CellContext`\[Epsilon]x0, \
$CellContext`\[Epsilon]y0, $CellContext`\[Epsilon]z0, \
$CellContext`\[Gamma]xy0, $CellContext`\[Gamma]yz0, $CellContext`\[Gamma]zx0, \
$CellContext`k$]; {$CellContext`p11, $CellContext`p21, $CellContext`p31, \
$CellContext`p41, $CellContext`p51, $CellContext`p61, $CellContext`p71, \
$CellContext`p81} = $CellContext`getCoordinates[$CellContext`\[Epsilon]x1, \
$CellContext`\[Epsilon]y1, $CellContext`\[Epsilon]z1, \
$CellContext`\[Gamma]xy1, $CellContext`\[Gamma]yz1, $CellContext`\[Gamma]zx1, \
$CellContext`k$]; {$CellContext`p12, $CellContext`p22, $CellContext`p32, \
$CellContext`p42, $CellContext`p52, $CellContext`p62, $CellContext`p72, \
$CellContext`p82} = $CellContext`getCoordinates[$CellContext`\[Epsilon]x2, \
$CellContext`\[Epsilon]y2, $CellContext`\[Epsilon]z2, \
$CellContext`\[Gamma]xy2, $CellContext`\[Gamma]yz2, $CellContext`\[Gamma]zx2, \
$CellContext`k$]; {$CellContext`p13, $CellContext`p23, $CellContext`p33, \
$CellContext`p43, $CellContext`p53, $CellContext`p63, $CellContext`p73, \
$CellContext`p83} = $CellContext`getCoordinates[$CellContext`\[Epsilon]x3, \
$CellContext`\[Epsilon]y3, $CellContext`\[Epsilon]z3, \
$CellContext`\[Gamma]xy3, $CellContext`\[Gamma]yz3, $CellContext`\[Gamma]zx3, \
$CellContext`k$]; {$CellContext`p14, $CellContext`p24, $CellContext`p34, \
$CellContext`p44, $CellContext`p54, $CellContext`p64, $CellContext`p74, \
$CellContext`p84} = $CellContext`getCoordinates[$CellContext`\[Epsilon]x4, \
$CellContext`\[Epsilon]y4, $CellContext`\[Epsilon]z4, \
$CellContext`\[Gamma]xy4, $CellContext`\[Gamma]yz4, $CellContext`\[Gamma]zx4, \
$CellContext`k$]; {$CellContext`p15, $CellContext`p25, $CellContext`p35, \
$CellContext`p45, $CellContext`p55, $CellContext`p65, $CellContext`p75, \
$CellContext`p85} = $CellContext`getCoordinates[$CellContext`\[Epsilon]x5, \
$CellContext`\[Epsilon]y5, $CellContext`\[Epsilon]z5, \
$CellContext`\[Gamma]xy5, $CellContext`\[Gamma]yz5, $CellContext`\[Gamma]zx5, \
$CellContext`k$]; {$CellContext`p16, $CellContext`p26, $CellContext`p36, \
$CellContext`p46, $CellContext`p56, $CellContext`p66, $CellContext`p76, \
$CellContext`p86} = $CellContext`getCoordinates[$CellContext`\[Epsilon]x6, \
$CellContext`\[Epsilon]y6, $CellContext`\[Epsilon]z6, \
$CellContext`\[Gamma]xy6, $CellContext`\[Gamma]yz6, $CellContext`\[Gamma]zx6, \
$CellContext`k$]; $CellContext`original = 
         If[$CellContext`opa3$$, {Black, Dashed, 
            
            Line[{{(-1)/2, (-1)/2, 1/2}, {1/2, (-1)/2, 1/2}, {
              1/2, (-1)/2, (-1)/2}, {(-1)/2, (-1)/2, (-1)/2}, {(-1)/2, (-1)/2,
                1/2}}], 
            
            Line[{{(-1)/2, 1/2, 1/2}, {1/2, 1/2, 1/2}, {
              1/2, 1/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2}, {(-1)/2, 1/2, 1/2}}], 
            Line[{{(-1)/2, (-1)/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2}}], 
            Line[{{1/2, (-1)/2, (-1)/2}, {1/2, 1/2, (-1)/2}}], 
            Line[{{(-1)/2, (-1)/2, 1/2}, {(-1)/2, 1/2, 1/2}}], 
            
            Line[{{1/2, (-1)/2, 1/2}, {
              1/2, 1/2, 1/2}}]}, {}]; $CellContext`settings = {
          PlotRange -> {{-1., 1.}, {-1., 1.}, {-1., 1.}}, Boxed -> False, 
           ImagePadding -> 0.1, ImageMargins -> 0, SphericalRegion -> True, 
           ViewAngle -> 0.03490658503988659, 
           ViewPoint -> {9.446837766166267, -23.937685481822157`, 
            12.113774712103389`}, 
           ViewVertical -> {-0.10353234010262227`, 0.2418056778647428, 
            0.965550443078499}, 
           ImageSize -> $CellContext`imz1}; $CellContext`text = {
           Text[
            Style[
            "x", Italic, FontSize -> 
             Scaled[$CellContext`fsz1]], {$CellContext`lps, 0, 0}], 
           Text[
            Style["y", Italic, FontSize -> Scaled[$CellContext`fsz1]], {
            0, $CellContext`lps, 0}], 
           Text[
            Style["z", Italic, FontSize -> Scaled[$CellContext`fsz1]], {
            0, 0, $CellContext`lps}]}; $CellContext`coordinate = {
           Arrowheads[0.02], 
           Map[
           Arrow[{{0, 0, 0}, #}]& , {{0.25, 0, 0}, {0, 0.25, 0}, {
             0, 0, 0.25}}]}; Grid[{{
            Grid[{{
               Row[{
                 Text[
                  Subscript["\[Sigma]", "x"]]}], 
               Row[{
                 Text[
                  Subscript["\[Sigma]", "y"]]}], 
               Row[{
                 Text[
                  Subscript["\[Sigma]", "z"]]}]}, {
               Style[
                Graphics3D[
                 Rotate[{
                   FaceForm[{
                    Opacity[0.3]}, White], 
                   Map[
                   Polygon[#]& , {{{$CellContext`p11, $CellContext`p21, \
$CellContext`p31, $CellContext`p41}, {$CellContext`p51, $CellContext`p61, \
$CellContext`p71, $CellContext`p81}, {$CellContext`p41, $CellContext`p31, \
$CellContext`p71, $CellContext`p81}, {$CellContext`p11, $CellContext`p21, \
$CellContext`p61, $CellContext`p51}, {$CellContext`p21, $CellContext`p61, \
$CellContext`p71, $CellContext`p31}, {$CellContext`p41, $CellContext`p81, \
$CellContext`p51, $CellContext`p11}}}], {Red, 
                    Arrowheads[$CellContext`ahd], 
                    Thickness[$CellContext`td], 
                    Map[Arrow[
                    
                    Tube[{(1/4) #, (
                    1/4 + $CellContext`arn \
($CellContext`\[Sigma]x$$/$CellContext`s)) #}]]& , {$CellContext`p21 + \
$CellContext`p31 + $CellContext`p61 + $CellContext`p71, $CellContext`p11 + \
$CellContext`p41 + $CellContext`p51 + $CellContext`p81}]}, \
$CellContext`original, $CellContext`coordinate, $CellContext`text}, 90 
                  Degree, {1, 0, 0}], $CellContext`settings, 
                 PreserveImageOptions -> 
                 If[$CellContext`reset1, $CellContext`reset1 = False; False, 
                   True]], Antialiasing -> True], 
               Style[
                Graphics3D[
                 Rotate[{
                   FaceForm[{
                    Opacity[0.3]}, White], 
                   Map[
                   Polygon[#]& , {{{$CellContext`p12, $CellContext`p22, \
$CellContext`p32, $CellContext`p42}, {$CellContext`p52, $CellContext`p62, \
$CellContext`p72, $CellContext`p82}, {$CellContext`p42, $CellContext`p32, \
$CellContext`p72, $CellContext`p82}, {$CellContext`p12, $CellContext`p22, \
$CellContext`p62, $CellContext`p52}, {$CellContext`p22, $CellContext`p62, \
$CellContext`p72, $CellContext`p32}, {$CellContext`p42, $CellContext`p82, \
$CellContext`p52, $CellContext`p12}}}], {Red, 
                    Arrowheads[$CellContext`ahd], 
                    Thickness[$CellContext`td], 
                    Map[Arrow[
                    
                    Tube[{(1/4) #, (
                    1/4 + $CellContext`arn \
($CellContext`\[Sigma]y$$/$CellContext`s)) #}]]& , {$CellContext`p32 + \
$CellContext`p42 + $CellContext`p72 + $CellContext`p82, $CellContext`p12 + \
$CellContext`p22 + $CellContext`p52 + $CellContext`p62}]}, \
$CellContext`original, $CellContext`coordinate, $CellContext`text}, 90 
                  Degree, {1, 0, 0}], $CellContext`settings, 
                 PreserveImageOptions -> 
                 If[$CellContext`reset2, $CellContext`reset2 = False; False, 
                   True]], Antialiasing -> True], 
               Style[
                Graphics3D[
                 Rotate[{
                   FaceForm[{
                    Opacity[0.3]}, White], 
                   Map[
                   Polygon[#]& , {{{$CellContext`p13, $CellContext`p23, \
$CellContext`p33, $CellContext`p43}, {$CellContext`p53, $CellContext`p63, \
$CellContext`p73, $CellContext`p83}, {$CellContext`p43, $CellContext`p33, \
$CellContext`p73, $CellContext`p83}, {$CellContext`p13, $CellContext`p23, \
$CellContext`p63, $CellContext`p53}, {$CellContext`p23, $CellContext`p63, \
$CellContext`p73, $CellContext`p33}, {$CellContext`p43, $CellContext`p83, \
$CellContext`p53, $CellContext`p13}}}], {Red, 
                    Arrowheads[$CellContext`ahd], 
                    Thickness[$CellContext`td], 
                    Map[Arrow[
                    
                    Tube[{(1/4) #, (
                    1/4 + $CellContext`arn \
($CellContext`\[Sigma]z$$/$CellContext`s)) #}]]& , {$CellContext`p13 + \
$CellContext`p23 + $CellContext`p33 + $CellContext`p43, $CellContext`p53 + \
$CellContext`p63 + $CellContext`p73 + $CellContext`p83}]}, \
$CellContext`original, $CellContext`coordinate, $CellContext`text}, 90 
                  Degree, {1, 0, 0}], $CellContext`settings, 
                 PreserveImageOptions -> 
                 If[$CellContext`reset3, $CellContext`reset3 = False; False, 
                   True]], Antialiasing -> True]}, {
               $CellContext`showStrain[({$CellContext`\[Epsilon]x1, \
$CellContext`\[Gamma]xy1, $CellContext`\[Gamma]zx1, \
$CellContext`\[Epsilon]y1, $CellContext`\[Gamma]yz1, \
$CellContext`\[Epsilon]z1}/$CellContext`exa$$) $CellContext`exa2, \
$CellContext`ft, $CellContext`opa2$$], 
               $CellContext`showStrain[({$CellContext`\[Epsilon]x2, \
$CellContext`\[Gamma]xy2, $CellContext`\[Gamma]zx2, \
$CellContext`\[Epsilon]y2, $CellContext`\[Gamma]yz2, \
$CellContext`\[Epsilon]z2}/$CellContext`exa$$) $CellContext`exa2, \
$CellContext`ft, $CellContext`opa2$$], 
               $CellContext`showStrain[({$CellContext`\[Epsilon]x3, \
$CellContext`\[Gamma]xy3, $CellContext`\[Gamma]zx3, \
$CellContext`\[Epsilon]y3, $CellContext`\[Gamma]yz3, \
$CellContext`\[Epsilon]z3}/$CellContext`exa$$) $CellContext`exa2, \
$CellContext`ft, $CellContext`opa2$$]}, {}, {
               Row[{
                 Text[
                  Subscript["\[Tau]", "xy"]]}], 
               Row[{
                 Text[
                  Subscript["\[Tau]", "yz"]]}], 
               Row[{
                 Text[
                  Subscript["\[Tau]", "zx"]]}]}, {
               Style[
                Graphics3D[
                 Rotate[{
                   FaceForm[{
                    Opacity[0.3]}, White], 
                   Map[
                   Polygon[#]& , {{{$CellContext`p14, $CellContext`p24, \
$CellContext`p34, $CellContext`p44}, {$CellContext`p54, $CellContext`p64, \
$CellContext`p74, $CellContext`p84}, {$CellContext`p44, $CellContext`p34, \
$CellContext`p74, $CellContext`p84}, {$CellContext`p14, $CellContext`p24, \
$CellContext`p64, $CellContext`p54}, {$CellContext`p24, $CellContext`p64, \
$CellContext`p74, $CellContext`p34}, {$CellContext`p44, $CellContext`p84, \
$CellContext`p54, $CellContext`p14}}}], {Red, 
                    Arrowheads[$CellContext`ahd], 
                    Thickness[$CellContext`td], 
                    Map[Arrow[
                    
                    Tube[{(1/4) 
                    Part[#, 
                    1] - (($CellContext`art \
($CellContext`\[Tau]xy$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 2], (1/4) 
                    Part[#, 
                    1] + (($CellContext`art \
($CellContext`\[Tau]xy$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 
                    2]}]]& , {{$CellContext`p34 + $CellContext`p44 + \
$CellContext`p74 + $CellContext`p84, $CellContext`p34 + $CellContext`p74 - \
$CellContext`p44 - $CellContext`p84}, {$CellContext`p14 + $CellContext`p24 + \
$CellContext`p54 + $CellContext`p64, -($CellContext`p24 + $CellContext`p64 - \
$CellContext`p14 - $CellContext`p54)}, {$CellContext`p24 + $CellContext`p34 + \
$CellContext`p64 + $CellContext`p74, $CellContext`p34 + $CellContext`p74 - \
$CellContext`p24 - $CellContext`p64}, {$CellContext`p14 + $CellContext`p44 + \
$CellContext`p54 + $CellContext`p84, -($CellContext`p44 + $CellContext`p84 - \
$CellContext`p14 - $CellContext`p54)}}]}, $CellContext`original, \
$CellContext`coordinate, $CellContext`text}, 90 Degree, {1, 0, 
                  0}], $CellContext`settings, PreserveImageOptions -> 
                 If[$CellContext`reset4, $CellContext`reset4 = False; False, 
                   True]], Antialiasing -> True], 
               Style[
                Graphics3D[
                 Rotate[{
                   FaceForm[{
                    Opacity[0.3]}, White], 
                   Map[
                   Polygon[#]& , {{{$CellContext`p15, $CellContext`p25, \
$CellContext`p35, $CellContext`p45}, {$CellContext`p55, $CellContext`p65, \
$CellContext`p75, $CellContext`p85}, {$CellContext`p45, $CellContext`p35, \
$CellContext`p75, $CellContext`p85}, {$CellContext`p15, $CellContext`p25, \
$CellContext`p65, $CellContext`p55}, {$CellContext`p25, $CellContext`p65, \
$CellContext`p75, $CellContext`p35}, {$CellContext`p45, $CellContext`p85, \
$CellContext`p55, $CellContext`p15}}}], {Red, 
                    Arrowheads[$CellContext`ahd], 
                    Thickness[$CellContext`td], 
                    Map[Arrow[
                    
                    Tube[{(1/4) 
                    Part[#, 
                    1] - (($CellContext`art \
($CellContext`\[Tau]yz$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 2], (1/4) 
                    Part[#, 
                    1] + (($CellContext`art \
($CellContext`\[Tau]yz$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 
                    2]}]]& , {{$CellContext`p35 + $CellContext`p45 + \
$CellContext`p75 + $CellContext`p85, $CellContext`p35 + $CellContext`p45 - \
$CellContext`p75 - $CellContext`p85}, {$CellContext`p15 + $CellContext`p25 + \
$CellContext`p55 + $CellContext`p65, -($CellContext`p15 + $CellContext`p25 - \
$CellContext`p55 - $CellContext`p65)}, {$CellContext`p15 + $CellContext`p25 + \
$CellContext`p35 + $CellContext`p45, $CellContext`p35 + $CellContext`p45 - \
$CellContext`p15 - $CellContext`p25}, {$CellContext`p55 + $CellContext`p65 + \
$CellContext`p75 + $CellContext`p85, -($CellContext`p75 + $CellContext`p85 - \
$CellContext`p55 - $CellContext`p65)}}]}, $CellContext`original, \
$CellContext`coordinate, $CellContext`text}, 90 Degree, {1, 0, 
                  0}], $CellContext`settings, PreserveImageOptions -> 
                 If[$CellContext`reset5, $CellContext`reset5 = False; False, 
                   True]], Antialiasing -> True], 
               Style[
                Graphics3D[
                 Rotate[{
                   FaceForm[{
                    Opacity[0.3]}, White], 
                   Map[
                   Polygon[#]& , {{{$CellContext`p16, $CellContext`p26, \
$CellContext`p36, $CellContext`p46}, {$CellContext`p56, $CellContext`p66, \
$CellContext`p76, $CellContext`p86}, {$CellContext`p46, $CellContext`p36, \
$CellContext`p76, $CellContext`p86}, {$CellContext`p16, $CellContext`p26, \
$CellContext`p66, $CellContext`p56}, {$CellContext`p26, $CellContext`p66, \
$CellContext`p76, $CellContext`p36}, {$CellContext`p46, $CellContext`p86, \
$CellContext`p56, $CellContext`p16}}}], {Red, 
                    Arrowheads[$CellContext`ahd], 
                    Thickness[$CellContext`td], 
                    Map[Arrow[
                    
                    Tube[{(1/4) 
                    Part[#, 
                    1] - (($CellContext`art \
($CellContext`\[Tau]zx$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 2], (1/4) 
                    Part[#, 
                    1] + (($CellContext`art \
($CellContext`\[Tau]zx$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 
                    2]}]]& , {{$CellContext`p26 + $CellContext`p36 + \
$CellContext`p66 + $CellContext`p76, $CellContext`p26 + $CellContext`p36 - \
$CellContext`p66 - $CellContext`p76}, {$CellContext`p16 + $CellContext`p46 + \
$CellContext`p56 + $CellContext`p86, -($CellContext`p16 + $CellContext`p46 - \
$CellContext`p56 - $CellContext`p86)}, {$CellContext`p16 + $CellContext`p26 + \
$CellContext`p36 + $CellContext`p46, $CellContext`p26 + $CellContext`p36 - \
$CellContext`p16 - $CellContext`p46}, {$CellContext`p56 + $CellContext`p66 + \
$CellContext`p76 + $CellContext`p86, -($CellContext`p66 + $CellContext`p76 - \
$CellContext`p56 - $CellContext`p86)}}]}, $CellContext`original, \
$CellContext`coordinate, $CellContext`text}, 90 Degree, {1, 0, 
                  0}], $CellContext`settings, PreserveImageOptions -> 
                 If[$CellContext`reset6, $CellContext`reset6 = False; False, 
                   True]], Antialiasing -> True]}, {
               $CellContext`showStrain[({$CellContext`\[Epsilon]x4, \
$CellContext`\[Gamma]xy4, $CellContext`\[Gamma]zx4, \
$CellContext`\[Epsilon]y4, $CellContext`\[Gamma]yz4, \
$CellContext`\[Epsilon]z4}/$CellContext`exa$$) $CellContext`exa2, \
$CellContext`ft, $CellContext`opa2$$], 
               $CellContext`showStrain[({$CellContext`\[Epsilon]x5, \
$CellContext`\[Gamma]xy5, $CellContext`\[Gamma]zx5, \
$CellContext`\[Epsilon]y5, $CellContext`\[Gamma]yz5, \
$CellContext`\[Epsilon]z5}/$CellContext`exa$$) $CellContext`exa2, \
$CellContext`ft, $CellContext`opa2$$], 
               $CellContext`showStrain[({$CellContext`\[Epsilon]x6, \
$CellContext`\[Gamma]xy6, $CellContext`\[Gamma]zx6, \
$CellContext`\[Epsilon]y6, $CellContext`\[Gamma]yz6, \
$CellContext`\[Epsilon]z6}/$CellContext`exa$$) $CellContext`exa2, \
$CellContext`ft, $CellContext`opa2$$]}}, Alignment -> Center, Frame -> True], 
            Grid[{{
               Style[
                Text["Superposition"], Bold, 20, 
                If[$CellContext`opa1$$ == 0, White, Black]]}, {
               Style[
                Graphics3D[
                 Rotate[{
                   Opacity[$CellContext`opa1$$], 
                   FaceForm[{
                    Opacity[0.3 $CellContext`opa1$$]}, White], 
                   EdgeForm[{
                    Opacity[$CellContext`opa1$$]}], 
                   Map[
                   Polygon[#]& , {{{$CellContext`p10, $CellContext`p20, \
$CellContext`p30, $CellContext`p40}, {$CellContext`p50, $CellContext`p60, \
$CellContext`p70, $CellContext`p80}, {$CellContext`p40, $CellContext`p30, \
$CellContext`p70, $CellContext`p80}, {$CellContext`p10, $CellContext`p20, \
$CellContext`p60, $CellContext`p50}, {$CellContext`p20, $CellContext`p60, \
$CellContext`p70, $CellContext`p30}, {$CellContext`p40, $CellContext`p80, \
$CellContext`p50, $CellContext`p10}}}], $CellContext`original, \
$CellContext`coordinate, Red, 
                   Arrowheads[$CellContext`ahs], 
                   Thickness[$CellContext`ts], 
                   Map[Arrow[
                    
                    Tube[{(1/4) #, (
                    1/4 + ($CellContext`sclsup $CellContext`arn) \
($CellContext`\[Sigma]x$$/$CellContext`s)) #}]]& , {$CellContext`p20 + \
$CellContext`p30 + $CellContext`p60 + $CellContext`p70, $CellContext`p10 + \
$CellContext`p40 + $CellContext`p50 + $CellContext`p80}], 
                   Map[Arrow[
                    
                    Tube[{(1/4) #, (
                    1/4 + ($CellContext`sclsup $CellContext`arn) \
($CellContext`\[Sigma]y$$/$CellContext`s)) #}]]& , {$CellContext`p30 + \
$CellContext`p40 + $CellContext`p70 + $CellContext`p80, $CellContext`p10 + \
$CellContext`p20 + $CellContext`p50 + $CellContext`p60}], 
                   Map[Arrow[
                    
                    Tube[{(1/4) #, (
                    1/4 + ($CellContext`sclsup $CellContext`arn) \
($CellContext`\[Sigma]z$$/$CellContext`s)) #}]]& , {$CellContext`p10 + \
$CellContext`p20 + $CellContext`p30 + $CellContext`p40, $CellContext`p50 + \
$CellContext`p60 + $CellContext`p70 + $CellContext`p80}], 
                   Map[Arrow[
                    
                    Tube[{(1/4) 
                    Part[#, 
                    1] - (($CellContext`art \
($CellContext`\[Tau]xy$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 2], (1/4) 
                    Part[#, 
                    1] + (($CellContext`art \
($CellContext`\[Tau]xy$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 
                    2]}]]& , {{$CellContext`p30 + $CellContext`p40 + \
$CellContext`p70 + $CellContext`p80, $CellContext`p30 + $CellContext`p70 - \
$CellContext`p40 - $CellContext`p80}, {$CellContext`p10 + $CellContext`p20 + \
$CellContext`p50 + $CellContext`p60, -($CellContext`p20 + $CellContext`p60 - \
$CellContext`p10 - $CellContext`p50)}, {$CellContext`p20 + $CellContext`p30 + \
$CellContext`p60 + $CellContext`p70, $CellContext`p30 + $CellContext`p70 - \
$CellContext`p20 - $CellContext`p60}, {$CellContext`p10 + $CellContext`p40 + \
$CellContext`p50 + $CellContext`p80, -($CellContext`p40 + $CellContext`p80 - \
$CellContext`p10 - $CellContext`p50)}}], 
                   Map[Arrow[
                    
                    Tube[{(1/4) 
                    Part[#, 
                    1] - (($CellContext`art \
($CellContext`\[Tau]yz$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 2], (1/4) 
                    Part[#, 
                    1] + (($CellContext`art \
($CellContext`\[Tau]yz$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 
                    2]}]]& , {{$CellContext`p30 + $CellContext`p40 + \
$CellContext`p70 + $CellContext`p80, $CellContext`p30 + $CellContext`p40 - \
$CellContext`p70 - $CellContext`p80}, {$CellContext`p10 + $CellContext`p20 + \
$CellContext`p50 + $CellContext`p60, -($CellContext`p10 + $CellContext`p20 - \
$CellContext`p50 - $CellContext`p60)}, {$CellContext`p10 + $CellContext`p20 + \
$CellContext`p30 + $CellContext`p40, $CellContext`p30 + $CellContext`p40 - \
$CellContext`p10 - $CellContext`p20}, {$CellContext`p50 + $CellContext`p60 + \
$CellContext`p70 + $CellContext`p80, -($CellContext`p70 + $CellContext`p80 - \
$CellContext`p50 - $CellContext`p60)}}], 
                   Map[Arrow[
                    
                    Tube[{(1/4) 
                    Part[#, 
                    1] - (($CellContext`art \
($CellContext`\[Tau]zx$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 2], (1/4) 
                    Part[#, 
                    1] + (($CellContext`art \
($CellContext`\[Tau]zx$$/$CellContext`\[Tau])) (1/2)) 
                    Part[#, 
                    2]}]]& , {{$CellContext`p20 + $CellContext`p30 + \
$CellContext`p60 + $CellContext`p70, $CellContext`p20 + $CellContext`p30 - \
$CellContext`p60 - $CellContext`p70}, {$CellContext`p10 + $CellContext`p40 + \
$CellContext`p50 + $CellContext`p80, -($CellContext`p10 + $CellContext`p40 - \
$CellContext`p50 - $CellContext`p80)}, {$CellContext`p10 + $CellContext`p20 + \
$CellContext`p30 + $CellContext`p40, $CellContext`p20 + $CellContext`p30 - \
$CellContext`p10 - $CellContext`p40}, {$CellContext`p50 + $CellContext`p60 + \
$CellContext`p70 + $CellContext`p80, -($CellContext`p60 + $CellContext`p70 - \
$CellContext`p50 - $CellContext`p80)}}], Black, $CellContext`text}, 90 
                  Degree, {1, 0, 0}], 
                 PlotRange -> {{-1., 1.}, {-1., 1.}, {-1., 1.}}, Boxed -> 
                 False, ImagePadding -> 0.1, ImageMargins -> 0, 
                 SphericalRegion -> True, ViewAngle -> 0.03490658503988659, 
                 ViewPoint -> {9.446837766166267, -23.937685481822157`, 
                  12.113774712103389`}, 
                 ViewVertical -> {-0.10353234010262227`, 0.2418056778647428, 
                  0.965550443078499}, ImageSize -> $CellContext`imz0, 
                 PreserveImageOptions -> 
                 If[$CellContext`reset$$, $CellContext`reset$$ = False; False,
                    True]], Antialiasing -> True]}, {
               $CellContext`showStrain[({$CellContext`\[Epsilon]x0, \
$CellContext`\[Gamma]xy0, $CellContext`\[Gamma]zx0, \
$CellContext`\[Epsilon]y0, $CellContext`\[Gamma]yz0, \
$CellContext`\[Epsilon]z0}/$CellContext`exa$$) $CellContext`exa2, 
                2 $CellContext`ft, 
                If[$CellContext`opa1$$ == 0, White, $CellContext`opa2$$]]}}, 
             Alignment -> Center, Frame -> True, 
             ItemStyle -> {Automatic, 3 -> Bold}]}}, Alignment -> Top]], 
      "Specifications" :> {{{$CellContext`\[Sigma]x$$, 0, ""}, -500, 500, 5., 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`\[Sigma]y$$, 0, ""}, -500, 500, 5., Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`\[Sigma]z$$, 0, ""}, -500, 500, 5., Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`\[Tau]xy$$, 0, ""}, -500, 500, 5., Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`\[Tau]yz$$, 0, ""}, -500, 500, 5., Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`\[Tau]zx$$, 0, ""}, -500, 500, 5., Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         6}, {{$CellContext`ey$$, 210, ""}, 50, 250, 10, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         7}, {{$CellContext`\[Nu]$$, 0.3, ""}, -1, 0.5, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         8}, {{$CellContext`exa$$, 50, ""}, 1, 100, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         9}, {{$CellContext`opa3$$, False, Null}, {
         True -> "On", False -> "Off"}, ControlType -> RadioButton, 
         ControlPlacement -> 10}, {{$CellContext`opa2$$, 
          GrayLevel[1], Null}, {GrayLevel[0] -> "On", GrayLevel[1] -> "Off"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         11}, {{$CellContext`opa1$$, 0, Null}, {1 -> "On", 0 -> "Off"}, 
         ControlType -> RadioButton, ControlPlacement -> 12}, 
        Grid[{{
           Grid[{{
              Row[{
                Text[
                 Style["Stress"]], 
                Text[" (MPa)"]}], SpanFromLeft}, {
              Row[{
                Text[
                 Subscript["\[Sigma]", "xx"]]}], 
              Manipulate`Place[1]}, {
              Row[{
                Text[
                 Subscript["\[Sigma]", "yy"]]}], 
              Manipulate`Place[2]}, {
              Row[{
                Text[
                 Subscript["\[Sigma]", "zz"]]}], 
              Manipulate`Place[3]}, {
              Row[{
                Text[
                 Subscript["\[Tau]", "xy"]]}], 
              Manipulate`Place[4]}, {
              Row[{
                Text[
                 Subscript["\[Tau]", "yz"]]}], 
              Manipulate`Place[5]}, {
              Row[{
                Text[
                 Subscript["\[Tau]", "zx"]]}], 
              Manipulate`Place[6]}}, Alignment -> Left]}, {}, {
           Grid[{{
              Grid[{{
                 Text["Young's Modulus (GPa)"]}, {
                 Manipulate`Place[7]}}, Alignment -> Left]}, {
              Grid[{{
                 Text["Poisson's Ratio"]}, {
                 Manipulate`Place[8]}}, Alignment -> Left]}, {
              Grid[{{
                 Row[{
                   Text[
                    Style["Deformation scaling"]]}]}, {
                 Manipulate`Place[9]}}, Alignment -> Left]}}, Alignment -> 
            Left]}, {
           Grid[{{
              Row[{
                Text["Show original"]}]}, {
              Manipulate`Place[10]}, {
              Row[{
                Text["Strain tensor"], 
                Text[" (\[Times]"], 
                Text[
                 Superscript["10", "-3"]], 
                Text[")"]}]}, {
              Manipulate`Place[11]}, {
              Text["Superposition"]}, {
              Manipulate`Place[12]}, {}, {
              Button[
               Text["reset view"], $CellContext`reset$$ = True, 
               ImageSize -> {95, 25}]}, {
              Button[
               Text[
               "reset stress"], $CellContext`\[Sigma]x$$ = 
                0; $CellContext`\[Sigma]y$$ = 0; $CellContext`\[Sigma]z$$ = 
                0; $CellContext`\[Tau]xy$$ = 0; $CellContext`\[Tau]yz$$ = 
                0; $CellContext`\[Tau]zx$$ = 0, ImageSize -> {95, 25}]}}, 
            Alignment -> Left]}}, Alignment -> 
         Left], {{$CellContext`reset$$, False}, 0, ControlType -> None}}, 
      "Options" :> {ControlPlacement -> Left, Alignment -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1603., {399., 408.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`numeric = 
       Element[#, Reals]& ; $CellContext`getCoordinates[
         PatternTest[
          Pattern[$CellContext`stx, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`sty, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`stz, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`stxy, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`styz, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`stzx, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`k, 
           Blank[]], $CellContext`numeric]] := 
       Module[{$CellContext`p1, $CellContext`p2, $CellContext`p3, \
$CellContext`p4, $CellContext`p5, $CellContext`p6, $CellContext`p7, \
$CellContext`p8}, $CellContext`a\[Tau]xy = 
          Sin[$CellContext`stxy/2]; $CellContext`a\[Tau]yz = 
          Sin[$CellContext`styz/2]; $CellContext`a\[Tau]zx = 
          Sin[$CellContext`stzx/
            2]; $CellContext`p1 = {(-1)/
             2 + $CellContext`k ((-$CellContext`stx)/
               2 - $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]zx/2), (-1)/
             2 + $CellContext`k ((-$CellContext`sty)/
               2 - $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]yz/2), 
            1/2 + $CellContext`k ($CellContext`stz/2 - $CellContext`a\[Tau]yz/
              2 - $CellContext`a\[Tau]zx/2)}; $CellContext`p2 = {
           1/2 + $CellContext`k ($CellContext`stx/2 - $CellContext`a\[Tau]xy/
              2 + $CellContext`a\[Tau]zx/2), (-1)/
             2 + $CellContext`k ((-$CellContext`sty)/
               2 + $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]yz/2), 
            1/2 + $CellContext`k ($CellContext`stz/2 - $CellContext`a\[Tau]yz/
              2 + $CellContext`a\[Tau]zx/2)}; $CellContext`p3 = {
           1/2 + $CellContext`k ($CellContext`stx/2 + $CellContext`a\[Tau]xy/
               2 + $CellContext`a\[Tau]zx/2), 
            1/2 + $CellContext`k ($CellContext`sty/2 + $CellContext`a\[Tau]xy/
               2 + $CellContext`a\[Tau]yz/2), 
            1/2 + $CellContext`k ($CellContext`stz/2 + $CellContext`a\[Tau]yz/
               2 + $CellContext`a\[Tau]zx/2)}; $CellContext`p4 = {(-1)/
             2 + $CellContext`k ((-$CellContext`stx)/
               2 + $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]zx/2), 
            1/2 + $CellContext`k ($CellContext`sty/2 - $CellContext`a\[Tau]xy/
              2 + $CellContext`a\[Tau]yz/2), 
            1/2 + $CellContext`k ($CellContext`stz/2 + $CellContext`a\[Tau]yz/
               2 - $CellContext`a\[Tau]zx/2)}; $CellContext`p5 = {(-1)/
             2 + $CellContext`k ((-$CellContext`stx)/
               2 - $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]zx/2), (-1)/
             2 + $CellContext`k ((-$CellContext`sty)/
               2 - $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]yz/2), (-1)/
             2 + $CellContext`k ((-$CellContext`stz)/
               2 - $CellContext`a\[Tau]yz/2 - $CellContext`a\[Tau]zx/
              2)}; $CellContext`p6 = {
           1/2 + $CellContext`k ($CellContext`stx/2 - $CellContext`a\[Tau]xy/
              2 - $CellContext`a\[Tau]zx/2), (-1)/
             2 + $CellContext`k ((-$CellContext`sty)/
               2 + $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]yz/2), (-1)/
             2 + $CellContext`k ((-$CellContext`stz)/
               2 - $CellContext`a\[Tau]yz/
              2 + $CellContext`a\[Tau]zx/2)}; $CellContext`p7 = {
           1/2 + $CellContext`k ($CellContext`stx/2 + $CellContext`a\[Tau]xy/
               2 - $CellContext`a\[Tau]zx/2), 
            1/2 + $CellContext`k ($CellContext`sty/2 + $CellContext`a\[Tau]xy/
               2 - $CellContext`a\[Tau]yz/2), (-1)/
             2 + $CellContext`k ((-$CellContext`stz)/
               2 + $CellContext`a\[Tau]yz/2 + $CellContext`a\[Tau]zx/
               2)}; $CellContext`p8 = {(-1)/
             2 + $CellContext`k ((-$CellContext`stx)/
               2 + $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]zx/2), 
            1/2 + $CellContext`k ($CellContext`sty/2 - $CellContext`a\[Tau]xy/
              2 - $CellContext`a\[Tau]yz/2), (-1)/
             2 + $CellContext`k ((-$CellContext`stz)/
               2 + $CellContext`a\[Tau]yz/2 - $CellContext`a\[Tau]zx/
              2)}; {$CellContext`p1, $CellContext`p2, $CellContext`p3, \
$CellContext`p4, $CellContext`p5, $CellContext`p6, $CellContext`p7, \
$CellContext`p8}]; $CellContext`padIt1[
         PatternTest[
          Pattern[$CellContext`v, 
           Blank[]], $CellContext`numeric], 
         Pattern[$CellContext`f, 
          Blank[List]]] := If[$CellContext`v != 0, 
         AccountingForm[$CellContext`v, $CellContext`f, 
          NumberSigns -> {"-", "+"}, NumberPadding -> {"0", "0"}, SignPadding -> 
          True], 
         AccountingForm[$CellContext`v, 1, NumberSigns -> {"", ""}, 
          NumberPadding -> {"0", "0"}, SignPadding -> 
          True]]; $CellContext`showStrain[{
          Pattern[$CellContext`s11, 
           Blank[]], 
          Pattern[$CellContext`s12, 
           Blank[]], 
          Pattern[$CellContext`s13, 
           Blank[]], 
          Pattern[$CellContext`s22, 
           Blank[]], 
          Pattern[$CellContext`s23, 
           Blank[]], 
          Pattern[$CellContext`s33, 
           Blank[]]}, 
         Pattern[$CellContext`ft, 
          Blank[]], 
         Pattern[$CellContext`straincolor, 
          Blank[]]] := Module[{}, 
         Style[
          Row[{
            Dynamic[
             TraditionalForm[{{
                $CellContext`padIt1[
                 N[$CellContext`s11], {3, 2}], 
                $CellContext`padIt1[
                 N[$CellContext`s12], {3, 2}], 
                $CellContext`padIt1[
                 N[$CellContext`s13], {3, 2}]}, {
                $CellContext`padIt1[
                 N[$CellContext`s12], {3, 2}], 
                $CellContext`padIt1[
                 N[$CellContext`s22], {3, 2}], 
                $CellContext`padIt1[
                 N[$CellContext`s23], {3, 2}]}, {
                $CellContext`padIt1[
                 N[$CellContext`s13], {3, 2}], 
                $CellContext`padIt1[
                 N[$CellContext`s23], {3, 2}], 
                $CellContext`padIt1[
                 N[$CellContext`s33], {3, 
                 2}]}}]]}], $CellContext`ft, $CellContext`straincolor]]); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center],

Cell["\<\
Reference: Nasser M. Abbasi, Cauchy and Engineering Strain Deformation in 3D, \
Mathematica demonstration module available at \
http://demonstrations.wolfram.com/CauchyAndEngineeringStrainDeformationIn3D/. \
\>", "Text"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 219, 7, 230, "Title"],
Cell[1708, 44, 1409, 22, 273, "Text"],
Cell[3120, 68, 46050, 883, 831, "Output"],
Cell[49173, 953, 230, 4, 74, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 5wpzXyF17QFZ@AgAzmMjHH#y *)
